==> glib-web-3.20.2.tgz: package/components/composable/dropable.js <==
import { computed, nextTick, watch, onMounted } from 'vue';
import Uploader from "../../utils/uploader";

function useDropableUtils() {
  const makeKey = () => Math.random().toString(36).slice(2, 7);

  class Item {
    constructor(options) {
      this.progress = { value: 0 };
      this.status = options.status;
      this.signedId = options.signedId;
      this._name = options.name;
      this._url = options.url;
      this._type = options.type;
      this.el = options.el;
    }

    isImage() {
      return this.type.startsWith('image');
    }

    get type() {
      if (this._type) {
        return this._type;
      }

      if (this.el) {
        return this.el.type;
      }

      return '';
    }

    get name() {
      if (this._name) {
        return this._name;
      }

      if (this.el) {
        return this.el.name;
      }

      return '';
    }

    get url() {
      if (this._url || !this.el) {
        return this._url;
      }

      return URL.createObjectURL(this.el);
    }
  }

  return { makeKey, Item };
}

function useFilesState(files) {
  const uploading = computed(() => Object.values(files.value).reduce((prev, curr) => prev || curr.status == 'pending', false));
  const uploaded = computed(() => Object.values(files.value).reduce((prev, curr) => prev && !!curr.signedId, true));

  return { uploading, uploaded };
}

function setBusyWhenUploading({ container, files }) {
  const setBusy = (container, value) => {
    const event = new Event('forms/setBusy', { bubbles: true });
    event.data = { value };
    container.value.dispatchEvent(event);
  };

  const { uploading } = useFilesState(files);

  watch(uploading, (val, oldVal) => {
    if (!container.value) return null;
    if (val) {
      setBusy(container, true);
    } else {
      setBusy(container, false);
    }
  });
}

function uploadFiles({ droppedFiles, files, directUploadUrl, accepts, responseMessages, container }) {
  const { makeKey, Item } = useDropableUtils();

  for (let index = 0; index < droppedFiles.length; index++) {
    // show new dropped file and track progress
    const key = makeKey();
    files.value[key] = new Item({ el: droppedFiles[index], status: 'pending' });

    const uploader = new Uploader(files.value[key].el, directUploadUrl, files.value[key].progress);

    // track progress
    uploader.directUploadWillStoreFileWithXHR = (request) => {
      request.upload.addEventListener("progress", event => {
        files.value[key].progress.value = (event.loaded / event.total) * 100;
      });

      // can be use for aborting request
      files.value[key].xhr = request;
    };

    // validate per file, skip if invalid
    if (!uploader.validateFile({ accepts: accepts })) {
      delete files.value[key];
      continue;
    }

    // upload per file
    uploader.start((error, blob) => {
      if (!error) {
        Object.assign(files.value[key], {
          status: 'completed',
          signedId: blob.signed_id,
          message: responseMessages['200']
        });
        // trigger form.vue onchange
        if (container.value) {
          nextTick(() => container.value.dispatchEvent(new Event('change', { bubbles: true })));
        }
      } else {
        const message = responseMessages[error.slice(-3) || 'else'];
        Object.assign(files.value[key], {
          status: 'failed',
          message: message
        });
      }
    });
  }
}

function useDropUpload({ accepts, onFinishUpload, onDragStyle, container, directUploadUrl, fileSelect, files }) {
  onMounted(() => {
    setBusyWhenUploading({ container, files });

    // handle style changes
    let dragEl = null;
    container.value.ondragenter = (event) => {
      dragEl = event.target;
      container.value.classList.add(...onDragStyle);
    };
    container.value.ondragleave = (event) => {
      if (dragEl == event.target) {
        container.value.classList.remove(...onDragStyle);
      }
    };

    // handle upload
    container.value.ondragover = (event) => event.preventDefault();
    container.value.ondrop = (event) => {
      event.preventDefault();
      uploadFiles({
        droppedFiles: event.dataTransfer.files,
        accepts,
        container,
        directUploadUrl,
        files,
        responseMessages: {}
      });
      container.value.classList.remove(...onDragStyle);
    };

    container.value.onclick = (event) => {
      const onchange = () => {
        uploadFiles(
          {
            droppedFiles: event.target.files,
            files: files,
            directUploadUrl,
            accepts,
            responseMessages: {},
            container
          }
        );
      };

      fileSelect.value.onchange = onchange;
      fileSelect.value.click();
    };

    // handle when all file uploaded, all files have signedIds
    const { uploaded } = useFilesState(files);
    watch(uploaded, (val, oldVal) => {
      if (val) {
        onFinishUpload(Object.values(files.value).map((file) => file.signedId));
      }
    });
  });

};

export { useDropUpload, useDropableUtils, setBusyWhenUploading, uploadFiles };

==> glib-web-3.20.6.tgz: package/components/composable/dropable.js <==
import { computed, watch, onMounted, nextTick } from 'vue';
import { triggerOnChange } from "./form";
import Uploader from "../../utils/uploader";
import { vueApp } from "../../store";

function useDropableUtils() {
  const makeKey = () => Math.random().toString(36).slice(2, 7);
  const signedIds = (files) => Object.values(files.value).map((file) => file.signedId);

  class Item {
    constructor(options) {
      this.progress = { value: 0 };
      this.status = options.status;
      this.signedId = options.signedId;
      this._name = options.name;
      this._url = options.url;
      this._type = options.type;
      this.el = options.el;
    }

    isImage() {
      return this.type.startsWith('image');
    }

    get type() {
      if (this._type) {
        return this._type;
      }

      if (this.el) {
        return this.el.type;
      }

      return '';
    }

    get name() {
      if (this._name) {
        return this._name;
      }

      if (this.el) {
        return this.el.name;
      }

      return '';
    }

    get url() {
      if (this._url || !this.el) {
        return this._url;
      }

      return URL.createObjectURL(this.el);
    }
  }

  return { makeKey, Item, signedIds };
}

function useFilesState(files) {
  const uploading = computed(() => Object.values(files.value).reduce((prev, curr) => prev || curr.status == 'pending', false));
  const uploaded = computed(() => Object.values(files.value).reduce((prev, curr) => prev && !!curr.signedId, true));

  return { uploading, uploaded };
}

function setBusyWhenUploading({ files }) {
  const { uploading } = useFilesState(files);

  watch(uploading, (val, oldVal) => {
    if (val) {
      vueApp.indicator = true;
    } else {
      vueApp.indicator = false;
    }
  });
}

function uploadFiles({ droppedFiles, files, directUploadUrl, accepts = {}, responseMessages = {}, container }) {
  const maxFileLength = accepts.maxFileLength || 1;

  if (droppedFiles.length > maxFileLength) {
    alert("Files exceed the maximum limit per upload");
    return;
  }

  const { makeKey, Item } = useDropableUtils();

  for (let index = 0; index < droppedFiles.length; index++) {
    // show new dropped file and track progress
    const key = makeKey();
    files.value[key] = new Item({ el: droppedFiles[index], status: 'pending' });

    const uploader = new Uploader(files.value[key].el, directUploadUrl, files.value[key].progress);

    // track progress
    uploader.directUploadWillStoreFileWithXHR = (request) => {
      request.upload.addEventListener("progress", event => {
        files.value[key].progress.value = (event.loaded / event.total) * 100;
      });

      // can be use for aborting request
      files.value[key].xhr = request;
    };

    // validate per file, skip if invalid
    if (!uploader.validateFile({ accepts: accepts })) {
      delete files.value[key];
      continue;
    }

    // upload per file
    uploader.start((error, blob) => {
      if (!error) {
        Object.assign(files.value[key], {
          status: 'completed',
          signedId: blob.signed_id,
          message: responseMessages['200']
        });
        // trigger form.vue onchange
        if (container && container.value) {
          triggerOnChange(container.value);
        }
      } else {
        const message = responseMessages[error.slice(-3) || 'else'];
        Object.assign(files.value[key], {
          status: 'failed',
          message: message
        });
      }
    });
  }
}

function useDropUpload({ accepts, onFinishUpload, onDragStyle, container, directUploadUrl, fileSelect, files }) {
  onMounted(() => {
    setBusyWhenUploading({ files });

    // handle style changes
    let dragEl = null;
    container.value.ondragenter = (event) => {
      dragEl = event.target;
      container.value.classList.add(...onDragStyle);
    };
    container.value.ondragleave = (event) => {
      if (dragEl == event.target) {
        container.value.classList.remove(...onDragStyle);
      }
    };

    // handle upload
    container.value.ondragover = (event) => event.preventDefault();
    container.value.ondrop = (event) => {
      event.preventDefault();
      uploadFiles({
        droppedFiles: event.dataTransfer.files,
        accepts,
        container,
        directUploadUrl,
        files,
        responseMessages: {}
      });
      container.value.classList.remove(...onDragStyle);
    };

    container.value.onclick = (event) => {
      const onchange = () => {
        uploadFiles(
          {
            droppedFiles: event.target.files,
            files: files,
            directUploadUrl,
            accepts,
            responseMessages: {},
            container
          }
        );
      };

      fileSelect.value.onchange = onchange;
      fileSelect.value.click();
    };

    // handle when all file uploaded, all files have signedIds
    const { uploaded } = useFilesState(files);
    watch(uploaded, (val, oldVal) => {
      if (val) {
        nextTick(() => onFinishUpload(Object.values(files.value).map((file) => file.signedId)));
      }
    });
  });

};

export { useDropUpload, useDropableUtils, setBusyWhenUploading, uploadFiles, useFilesState };
